package com.hikcreate.edl.pub.web.mobile.api.controller;

import cn.hutool.core.date.DateTime;
import com.hikcreate.edl.pub.web.mobile.domain.IBindService;
import com.hikcreate.edl.pub.web.mobile.infra.core.Result;
import com.hikcreate.edl.pub.web.mobile.infra.core.enums.ResultCode;
import com.hikcreate.edl.pub.web.mobile.infra.core.page.PageResult;
import com.hikcreate.edl.pub.web.mobile.infra.data.mapper.BindInfoMapper;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfo;
import com.hikcreate.edl.pub.web.mobile.infra.model.BindInfoQuery;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;

/**
 * 绑定信息的controller
 *
 * @author: xieshixiang
 * @time：2020/6/18 15:59
 **/
@RestController
@RequestMapping("/vehicle")
@Slf4j
public class BindInfoControlller extends BaseController {

    @Autowired
    IBindService service;
    @Resource
    BindInfoMapper mapper;


    /**
     * 绑定用户信息的接口
     *
     * @param info
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 10:27
     */
    @PostMapping("bind")
    public Result bindInfo(@RequestBody BindInfo info) {
        if (info == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        return service.bind(info);
    }


    /**
     * 解绑用户信息的接口
     *
     * @param info
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 10:27
     */
    @PostMapping("unbind")
    public Result unbindInfo(@RequestBody BindInfo info) {
        if (info == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        info.setStatus("0");
        info.setEditorTime(DateTime.now());
        return mapper.updateById(info) > 0 ? Result.successResult() : Result.errorResult();
    }

    /**
     * 绑定信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 10:31
     */
    @PostMapping("query")
    public Result bindInfoQery(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "参数不能为空");
        }
        return Result.successResult(mapper.selectByQuery(query));
    }

    /**
     * 年检信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 10:32
     */
    @PostMapping("yearCheckInfo")
    public Result yearCheckInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.yearCheckInfo(query);
    }

    /**
     * 驾照信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @PostMapping("violationInfo")
    public Result violationInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.violationInfo(query);
    }

    @PostMapping("insuranceInfo")
    public Result insuranceInfo(@RequestBody BindInfoQuery query){
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.insuranceInfo(query);
    }

    /**
     * 驾照信息查询接口
     *
     * @param query
     * @return Result
     * @author: xsx
     * @date: 2020/6/19 16:28
     */
    @PostMapping("drivingLicenseInfo")
    public Result drivingLicenseInfo(@RequestBody BindInfoQuery query) {
        if (query == null) {
            return Result.errorResult(ResultCode.PARAMETER_ERROR, "鉴权失败");
        }
        return service.drivingLicenseInfo(query);
    }


}
